@@ -3,7 +3,7 @@ package Dancer2::Plugin::OAuth2::Server;
 use strict;
 use warnings;
 use 5.008_005;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 use Dancer2::Plugin;
 use URI;
 use URI::QueryParam;
@@ -84,7 +84,22 @@ sub _authorization_request {
                 error_uri         => '',
             }
         );
-        return;
+    }
+
+    my $state_required = $settings->{state_required} // 0;
+    if(
+        $state_required
+            and ! defined $state
+            and ! length $state
+    ) {
+        $dsl->status( 400 );
+        return $dsl->to_json(
+            {
+                error             => 'invalid_request',
+                error_description => 'the request was missing : state ',
+                error_uri         => '',
+            }
+        );
     }
 
     my $uri = URI->new( $url );
@@ -265,6 +280,14 @@ Port of Mojolicious implementation : https://github.com/G3S/mojolicious-plugin-o
 
 Dancer2::Plugin::OAuth2::Server is a port of Mojolicious plugin for OAuth2 server
 
+=head1 CONFIGURATION
+
+=head2 state_required
+
+State is optional in the sepcifications, however using state is really recommended to have a safe implementation on client side.
+Client should send state and verify it, switching state_required to 1 make state a required parameter when trying to get 
+the authorization code
+
 =head1 AUTHOR
 
 Pierre Vigier E<lt>pierre.vigier@gmail.comE<gt>
